==> nextcloud-18.0.4.tgz: nextcloud/apps/firstrunwizard/l10n/he.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
    "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
    "First run wizard" : "אשף ההפעלה הראשונית",
    "Add your profile information! For example your email is needed to reset your password." : "נא להוסיף את פרטי הפרופיל שלך! למשל, כתובת הדוא״ל שלך נחוצה לטובת איפוס הססמה שלך.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר תמונת פרופיל ושם מלא לצורך זיהוי פשוט יותר בין כל התכונות השונות.",
    "Add your profile information! Set a full name for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר שם מלא כדי להקל על הזיהוי בין כל התכונות השונות.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר תמונת פרופיל לצורך זיהוי פשוט יותר בין כל התכונות השונות.",
    "About" : "על אודות",
    "A welcome and introduction wizard for Nextcloud" : "אשף קבלת פנים והיכרות ל־Nextcloud",
    "Start using Nextcloud" : "להתחיל להשתמש ב־Nextcloud",
    "Extend your cloud" : "הרחבת הענן שלך",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "ניתן למצוא למעלה מ־100 יישומונים בחנות היישומונים של Nextcloud כדי להתאים את הענן לצרכיך:",
    "Groupware apps like Calendar, Contacts, Mail" : "יישומונים לעבודה קבוצתית כמו לוח שנה, אנשי קשר, דוא״ל",
    "Communication with Nextcloud Talk" : "תקשורת עם Nextcloud Talk",
    "Collaboration apps for document editing" : "יישומוני שיתופי פעולה לעריכת מסמכים",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "תכונות אימות ואבטחה כגון אימות דו־שלבי, SSO והגנה מפני כופרות",
    "Browse the app store" : "עיון בחנות היישומונים",
    "Stay in sync" : "תמיד מסונכרן",
    "Nextcloud gives you access to your files wherever you are." : "עם Nextcloud יש לך גישה לקבצים שלך מכל מקום.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "הלקוחות הפשוטים לשימוש זמינים לכל הפלטפורמות לשולחן העבודה ולנייד ללא עלות!",
    "Get the apps to sync your files" : "ניתן להוריד את היישומים כדי לסנכרן את הקבצים שלך",
    "Desktop client" : "לקוח לשולחן עבודה",
    "Android app" : "יישומון Android",
    "iOS app" : "יישומון iOS",
    "Connect your desktop apps to %s" : "חיבור אפליקציית המחשב האישי אל %s",
    "Connect your calendar" : "חיבור היומן שלך",
    "Connect your contacts" : "חיבור אנשי הקשר שלך",
    "Access files via WebDAV" : "גישה לקבצים דרך WebDAV",
    "Get help" : "קבלת עזרה",
    "Get more information" : "קבלת מידע נוסף",
    "The Nextcloud documentation for home users:" : "תיעוד Nextcloud למשתמשים ביתיים:",
    "User manual" : "מדריך משתמש",
    "Admin manual" : "מדריך מנהל",
    "Developer manual" : "מדריך מפתח",
    "You can also ask for help in our community support channels:" : "ניתן לבקש עזרה בערוצי התמיכה הקהילתיים שלנו:",
    "the Nextcloud forums" : "הפורומים של Nextcloud",
    "the Nextcloud IRC chat channel on freenode.net" : "ערוץ ה־IRC של Nextcloud ב־freenode.net",
    "Start contributing" : "להתחיל לתרום",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "מעניין אותך לקבל שיפורים ל־Nextcloud שלך? מצאת תקלה כלשהי? מעניין אותך לסייע לתרגם, לקדם או לתעד את Nextcloud?",
    "Become part of the Community" : "להפוך לחלק מהקהילה",
    "Enterprise support" : "תמיכה מסחרית",
    "Get enterprise support" : "קבלת תמיכה עסקית",
    "A safe home for all your data" : "בית בטוח לכל הנתונים שלך",
    "Host your data and files where you decide" : "אירוח הנתונים והקבצים שלך במיקום לבחירתך",
    "Open Standards and Interoperability" : "תקנים פתוחים ותאימות לשלל מערכות",
    "100%% Open Source & community-focused" : "100%% קוד פתוח ומוכוון קהילה",
    "Learn more about %s" : "מידע נוסף על %s",
    "Connect other apps to %s" : "חיבור של יישומונים אחרים אל %s",
    "Server address" : "כתובת שרת",
    "Copy link" : "העתקת קישור",
    "Previous" : "הקודם",
    "Next" : "הבא"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-20.0.8p0.tgz: nextcloud/apps/firstrunwizard/l10n/he.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
    "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
    "First run wizard" : "אשף ההפעלה הראשונית",
    "Add your profile information! For example your email is needed to reset your password." : "נא להוסיף את פרטי הפרופיל שלך! למשל, כתובת הדוא״ל שלך נחוצה לטובת איפוס הססמה שלך.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר תמונת פרופיל ושם מלא לצורך זיהוי פשוט יותר בין כל התכונות השונות.",
    "Add your profile information! Set a full name for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר שם מלא כדי להקל על הזיהוי בין כל התכונות השונות.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "נא להוסיף את פרטי הפרופיל שלך! ניתן להגדיר תמונת פרופיל לצורך זיהוי פשוט יותר בין כל התכונות השונות.",
    "App recommendation: Nextcloud Calendar" : "המלצת יישומון: יומן מבית Nextcloud",
    "Schedule work & meetings, synced with all your devices." : "תזמון עבודה ופגישות בסנכרון עם כל המכשירים שלך.",
    "App recommendation: Nextcloud Contacts" : "המלצת יישומון: אנשי קשר מבית Nextcloud",
    "Keep your colleagues and friends in one place without leaking their private info." : "עמיתים לעבודה וחברים מרוכזים במקום אחד מבלי זליגה של הפרטים האישיים שלהם.",
    "App recommendation: Nextcloud Mail" : "המלצת יישומון: דוא״ל מבית Nextcloud",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "יישומון דוא״ל פשוט שמשתלב בצורה נחמדה עם הקבצים, אנשי הקשר והיומן.",
    "App recommendation: Tasks" : "המלצת יישומון: משימות",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "סנכרון משימות בין מכשירים שונים עם ה־Nextcloud שלך ולערוך אותן באופן מקוון.",
    "About" : "על אודות",
    "A welcome and introduction wizard for Nextcloud" : "אשף קבלת פנים והיכרות ל־Nextcloud",
    "Start using Nextcloud" : "להתחיל להשתמש ב־Nextcloud",
    "Extend your cloud" : "הרחבת הענן שלך",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "ניתן למצוא למעלה מ־100 יישומונים בחנות היישומונים של Nextcloud כדי להתאים את הענן לצרכיך:",
    "Groupware apps like Calendar, Contacts, Mail" : "יישומונים לעבודה קבוצתית כמו לוח שנה, אנשי קשר, דוא״ל",
    "Communication with Nextcloud Talk" : "תקשורת עם Nextcloud Talk",
    "Collaboration apps for document editing" : "יישומוני שיתופי פעולה לעריכת מסמכים",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "תכונות אימות ואבטחה כגון אימות דו־שלבי, SSO והגנה מפני כופרות",
    "Browse the app store" : "עיון בחנות היישומונים",
    "Stay in sync" : "תמיד מסונכרן",
    "Nextcloud gives you access to your files wherever you are." : "עם Nextcloud יש לך גישה לקבצים שלך מכל מקום.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "הלקוחות הפשוטים לשימוש זמינים לכל הפלטפורמות לשולחן העבודה ולנייד ללא עלות!",
    "Get the apps to sync your files" : "ניתן להוריד את היישומים כדי לסנכרן את הקבצים שלך",
    "Desktop client" : "לקוח לשולחן עבודה",
    "Android app" : "יישומון Android",
    "iOS app" : "יישומון iOS",
    "Connect your desktop apps to %s" : "חיבור אפליקציית המחשב האישי אל %s",
    "Connect your calendar" : "חיבור היומן שלך",
    "Connect your contacts" : "חיבור אנשי הקשר שלך",
    "Access files via WebDAV" : "גישה לקבצים דרך WebDAV",
    "Get help" : "קבלת עזרה",
    "Get more information" : "קבלת מידע נוסף",
    "The Nextcloud documentation for home users:" : "תיעוד Nextcloud למשתמשים ביתיים:",
    "User manual" : "מדריך משתמש",
    "Admin manual" : "מדריך מנהל",
    "Developer manual" : "מדריך מפתח",
    "You can also ask for help in our community support channels:" : "ניתן לבקש עזרה בערוצי התמיכה הקהילתיים שלנו:",
    "the Nextcloud forums" : "הפורומים של Nextcloud",
    "the Nextcloud IRC chat channel on freenode.net" : "ערוץ ה־IRC של Nextcloud ב־freenode.net",
    "Start contributing" : "להתחיל לתרום",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "מעניין אותך לקבל שיפורים ל־Nextcloud שלך? מצאת תקלה כלשהי? מעניין אותך לסייע לתרגם, לקדם או לתעד את Nextcloud?",
    "Become part of the Community" : "להפוך לחלק מהקהילה",
    "Enterprise support" : "תמיכה מסחרית",
    "Get enterprise support" : "קבלת תמיכה עסקית",
    "A safe home for all your data" : "בית בטוח לכל הנתונים שלך",
    "Host your data and files where you decide" : "אירוח הנתונים והקבצים שלך במיקום לבחירתך",
    "Open Standards and Interoperability" : "תקנים פתוחים ותאימות לשלל מערכות",
    "100%% Open Source & community-focused" : "100%% קוד פתוח ומוכוון קהילה",
    "Learn more about %s" : "מידע נוסף על %s",
    "Connect other apps to %s" : "חיבור של יישומונים אחרים אל %s",
    "Server address" : "כתובת שרת",
    "Use this link to connect your apps and desktop client to this server:" : "יש להשתמש בקישור הזה כדי לחבר את היישומונים ואת לקוח שולחן העבודה שלך לשרת הזה:",
    "Copy link" : "העתקת קישור",
    "Previous" : "הקודם",
    "Next" : "הבא"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
